@@ -10,11 +10,8 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <assert.h>
-
 #include <ctype.h>
-#ifdef _MSC_VER
-#pragma warning(disable: 4786)
-#endif
+
 #include <string>
 
 #include "ILexer.h"
